#
# spec file for package python-platformio
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-platformio
Version:        6.1.5
Release:        2.7
Summary:        New Generation Ecosystem for Embedded Development
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/platformio/platformio-core
Source0:        https://files.pythonhosted.org/packages/source/p/platformio/platformio-%{version}.tar.gz
Source99:       python-platformio.rpmlintrc
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-aiofiles >= 0.8
Requires:       python-ajsonrpc >= 1
Requires:       python-bottle >= 0.12
Requires:       python-click >= 8.0.4
Requires:       python-colorama
Requires:       python-marshmallow >= 3
Requires:       python-pyelftools >= 0.27
Requires:       python-pyserial >= 3.5
Requires:       python-requests >= 2
Requires:       python-semantic_version >= 2.10
Requires:       python-starlette >= 0.20
Requires:       python-tabulate >= 0.8
# dropping requirement to 0.16 instead of 0.18, setup.py asks for 0.18 since python 3.7
Requires:       python-uvicorn >= 0.16
# dropping requirement to 1.0 instead of 1.1, setup.py asks for 1.1 since python 3.7
Requires:       python-wsproto >= 1.0
Requires:       python-zeroconf
Requires(post): update-alternatives
Requires(postun):update-alternatives

%python_subpackages

%description
PlatformIO is a cross-platform, cross-architecture, multiple framework,
professional tool for embedded systems engineers and for software developers
who write applications for embedded products.

%prep
%setup -q -n platformio-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# mv because of gh#platformio/platformio-core#4458
%{python_expand mv %{buildroot}%{$python_sitelib}/scripts %{buildroot}%{$python_sitelib}/platformio
%fdupes %{buildroot}%{$python_sitelib}
}

%python_clone -a %{buildroot}%{_bindir}/pio
%python_clone -a %{buildroot}%{_bindir}/piodebuggdb
%python_clone -a %{buildroot}%{_bindir}/platformio

%post
%{python_install_alternative pio piodebuggdb platformio}

%postun
%{python_uninstall_alternative pio piodebuggdb platformio}

%files %{python_files}
%python_alternative %{_bindir}/pio
%python_alternative %{_bindir}/piodebuggdb
%python_alternative %{_bindir}/platformio
%{python_sitelib}/platformio
%{python_sitelib}/platformio-%{version}*-info

%changelog
* Thu Nov 10 2022 Matej Cepl <mcepl@suse.com>
- Switch to wheel build/install, move scripts/ directory to the
  packages's namespace (see gh#platformio/platformio-core#4458).
- Add python-platformio.rpmlintrc to avoid false positives.
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to versino 6.1.5
  * Added a new enable_proxy_strict_ssl setting to disable the proxy server certificate verification (issue #4432)
  * Documented PlatformIO Core Proxy Configuration
  * Speeded up device port finder by avoiding loading board HWIDs from development platforms
  * Improved caching of build metadata in debug mode
  * Fixed an issue when pio pkg install --storage-dir command requires PlatformIO project (issue #4410)
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 6.1.4 (2022-08-12)
  Added support for accepting the original FileNode environment in a “callback” function when using Build Middlewares (pull #4380)
  Improved device port finder when using dual channel UART converter (issue #4367)
  Improved project dependency resolving when using the pio project init --ide command
  Upgraded build engine to the SCons 4.4.0 (release notes)
  Keep custom “unwantedRecommendations” when generating projects for VSCode (issue #4383)
  Do not resolve project dependencies for the cleanall target (issue #4344)
  Warn about calling “env.BuildSources” in a POST-type script (issue #4385)
  Fixed an issue when escaping macros/defines for IDE integration (issue #4360)
  Fixed an issue when the “cleanall” target removes dependencies from all working environments (issue #4386)
* Mon Sep 26 2022 Matej Cepl <mcepl@suse.com>
- Remove less-than Requires … it is just asking for pain without
  any good reason.
* Mon Jul 25 2022 Henning Wülpern <hwuelpern@gmail.com>
- update to 6.1.3:
  * full list of changes beginning from version 5.2.1 at
    https://github.com/platformio/platformio-core/blob/v5.2.5/HISTORY.rst
  * full list of changes beginning from version 5.2.5 at
    https://docs.platformio.org/en/latest/core/history.html
- updated dependency versions according to setup.py
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 5.2.1:
  * Clean a build environment and installed library dependencies using a new
    cleanall target
  * Override a default library builder via a new builder field in a build group
    of library.json manifest
  * Updated Cppcheck v2.6 with new checks, increased reliability of advanced
    addons (MISRA/CERT) and various improvements
  * Handle the "test" folder as a part of CLion project
  * Improved handling of a library root based on "Conan" or "CMake" build systems
  * Fixed a "KeyError: Invalid board option 'build.cpu'" when using a
    precompiled library with a board that does not have a CPU field in the
    manifest
  * Fixed a "FileExist" error when the platformio ci command is used in pair
    with the --keep-build-dir option (issue #4011)
  * Fixed an issue with draft values of C++ language standards that broke
    static analysis via Cppcheck
* Sun Nov  1 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.0.2:
  * Improved “core.call” RPC for PlatformIO Home
  * Fixed a “KeyError: ‘versions’” when dependency does not exist in the
  registry
  * Fixed an issue with GCC linker when “native” dev-platform is used in pair
  with library dependencies
  * Fixed an “AssertionError: ensure_dir_exists” when checking library updates
  from simultaneous subprocesses
  * Fixed an issue when pio package publish command removes original archive
  after submitting to the registry
  * Fixed an issue when multiple pio lib install command with the same local
  library results in duplicates in lib_deps (issue #3715) Fixed an issue with
  a “wrong” timestamp in device monitor output using “time” filter
* Fri Oct  9 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.0.1:
  * Integration with the new PlatformIO Trusted Registry
  * Integration with the new Account Management System
  * New Package Management System
  * see https://docs.platformio.org/page/core/migration.html  for migrating from 4.x
  * full list of changes at https://docs.platformio.org/en/latest/core/history.html
* Fri Aug 28 2020 Dirk Mueller <dmueller@suse.com>
- Initial package (4.3.4)
